"use client";

import React, { useState, useEffect } from "react";
import { useRouter } from "next/navigation";
import { motion } from "framer-motion";
import axios from "@/services/APIservices";

const FormInput = ({ type, id, label, placeholder, className, required, value, onChange }) => {
  return (
    <div className={`${className}`}>
      <label htmlFor={id} className="block text-sm font-medium text-gray-700">
        {label}
      </label>
      <div className="mt-1">
        <input
          type={type}
          id={id}
          name={id}
          placeholder={placeholder}
          className="shadow-sm focus:ring-blue-500 focus:border-blue-500 block w-full sm:text-sm border-gray-300 rounded-md"
          required={required}
          value={value}
          onChange={onChange}
        />
      </div>
    </div>
  );
};

const Form = () => {
  const [isLoading, setIsLoading] = useState(false);
  const [adminData, setAdminData] = useState({});
  const [admins, setAdmins] = useState([]); // State for all admin details
  const [flashMessage, setFlashMessage] = useState(""); // Flash message state
  const router = useRouter();

  // Fetch admin details for form and table on component mount
  useEffect(() => {
    fetchAdminDetails();
  }, []);

  const fetchAdminDetails = async () => {
    try {
      const response = await axios.get("/api/admin");
      if (response.data.length > 0) {
        setAdminData(response.data[0]); // Set the first admin record in the form
        setAdmins(response.data); // Populate all admin records for the table
      }
    } catch (error) {
      console.error("Error fetching admin details:", error);
    }
  };

  const handleInputChange = (e) => {
    const { id, value } = e.target;
    setAdminData({ ...adminData, [id]: value });
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    setIsLoading(true);

    // Check if the provided name and email match any admin details
    const isAdmin = admins.some(
      (admin) => admin.name === adminData.name && admin.email === adminData.email
    );

    if (isAdmin) {
      // Redirect to admin dashboard
      router.push("/admin/admin_dash");
    } else {
      // Show flash message if not an admin
      setFlashMessage("Not an admin. Please check your details.");
      setTimeout(() => setFlashMessage(""), 3000); // Clear message after 3 seconds
    }

    setIsLoading(false);
  };

  return (
    <div className="flex flex-col md:flex-row items-start justify-center gap-8 w-full p-4 sm:p-6 md:p-8">
      {/* Form Section */}
      <div className="w-full max-w-md">
        <h1 className="text-center text-3xl md:text-4xl font-bold mb-8 bg-gradient-to-r from-blue-600 to-blue-800 bg-clip-text text-transparent font-sans tracking-tight">
          Admin Login
        </h1>

        {flashMessage && (
          <motion.div
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            exit={{ opacity: 0 }}
            className="text-red-600 text-sm font-medium text-center mb-4"
          >
            {flashMessage}
          </motion.div>
        )}

        <motion.div
          initial={{ opacity: 0, y: 20 }}
          animate={{ opacity: 1, y: 0 }}
          transition={{ duration: 0.3 }}
        >
          <form onSubmit={handleSubmit} className="w-full space-y-4">
            <FormInput
              type="text"
              id="name"
              label="Name"
              placeholder="Enter admin name"
              className="w-full"
              required
              value={adminData.name || ""}
              onChange={handleInputChange}
            />
            <FormInput
              type="email"
              id="email"
              label="Email"
              placeholder="Enter admin email"
              className="w-full"
              required
              value={adminData.email || ""}
              onChange={handleInputChange}
            />
            <motion.button
              type="submit"
              className="w-full bg-blue-500 text-white rounded-lg py-3 px-4 hover:bg-blue-600 transition-colors text-sm md:text-base disabled:opacity-50 disabled:cursor-not-allowed flex items-center justify-center"
              whileHover={{ scale: 1.02 }}
              whileTap={{ scale: 0.98 }}
              disabled={isLoading}
            >
              {isLoading ? (
                <span className="inline-block animate-spin rounded-full h-4 w-4 border-t-2 border-white mr-2" />
              ) : null}
              Login
            </motion.button>
          </form>
        </motion.div>
      </div>

      {/* Admin Table Section */}
      <div className="w-full max-w-3xl">
        <h2 className="text-xl font-bold mb-4">All Admin Details</h2>
        <div className="overflow-x-auto">
          <table className="min-w-full bg-white border border-gray-300 rounded-lg">
            <thead>
              <tr>
                <th className="px-4 py-2 border-b text-left">ID</th>
                <th className="px-4 py-2 border-b text-left">Name</th>
                <th className="px-4 py-2 border-b text-left">Email</th>
                <th className="px-4 py-2 border-b text-left">Role</th>
                <th className="px-4 py-2 border-b text-left">Status</th>
                <th className="px-4 py-2 border-b text-left">Phone</th>
                <th className="px-4 py-2 border-b text-left">Profile Photo</th>
              </tr>
            </thead>
            <tbody>
              {admins.map((admin) => (
                <tr key={admin.id} className="hover:bg-gray-100">
                  <td className="px-4 py-2 border-b">{admin.id}</td>
                  <td className="px-4 py-2 border-b">{admin.name}</td>
                  <td className="px-4 py-2 border-b">{admin.email}</td>
                  <td className="px-4 py-2 border-b">{admin.role}</td>
                  <td className="px-4 py-2 border-b">{admin.status}</td>
                  <td className="px-4 py-2 border-b">{admin.phone_number || "N/A"}</td>
                  <td className="px-4 py-2 border-b">
                    {admin.profilePhoto ? (
                      <img
                        src={admin.profilePhoto}
                        alt="Profile"
                        className="h-10 w-10 rounded-full object-cover"
                      />
                    ) : (
                      "N/A"
                    )}
                  </td>
                </tr>
              ))}
            </tbody>
          </table>
        </div>
      </div>
    </div>
  );
};

export default Form;
